@@ -1,8 +1,8 @@
 ######################################################################
 package JavaScript::SpiderMonkey;
 ######################################################################
-# Revision:     $Revision: 1.6 $
-# Last Checkin: $Date: 2006/07/28 09:36:39 $
+# Revision:     $Revision: 1.7 $
+# Last Checkin: $Date: 2007/06/08 19:03:08 $
 # By:           $Author: thomas_busch $
 #
 # Author: Mike Schilli m@perlmeister.com, 2002
@@ -80,7 +80,7 @@ use Log::Log4perl qw(:easy);
 require Exporter;
 require DynaLoader;
 
-our $VERSION     = '0.17';
+our $VERSION     = '0.18';
 our @ISA         = qw(Exporter DynaLoader);
 our %EXPORT_TAGS = ( 'all' => [ qw() ] );
 our @EXPORT_OK   = ( @{ $EXPORT_TAGS{'all'} } );
@@ -470,7 +470,7 @@ sub object_by_path {
                 DEBUG "Setting $path to predefined object";
                 $obj = JavaScript::SpiderMonkey::JS_DefineObject(
                        $self->{context}, $obj, $part, 
-                       JavaScript::SpiderMonkey::JS_GetClass($newobj), 
+                       JavaScript::SpiderMonkey::JS_GetClass($self->{context}, $newobj), 
                        $newobj);
             } else {
                 $obj = JavaScript::SpiderMonkey::JS_DefineObject(
@@ -546,6 +546,22 @@ sub eval {
     return $ok;
 }
 
+##################################################
+
+=head2 $js-E<gt>set_max_branch_operations($max_branch_operations)
+
+Set the maximum number of allowed branch operations. This protects
+against infinite loops and guarantees that the eval operation
+will terminate.
+
+=cut
+##################################################
+sub set_max_branch_operations {
+##################################################
+    my ($self, $max_branch_operations) = @_;
+    JavaScript::SpiderMonkey::JS_SetMaxBranchOperations($self->{context}, $max_branch_operations);
+}
+
 ##################################################
 sub dump {
 ##################################################
@@ -575,16 +591,16 @@ __END__
 
 First, get the latest SpiderMonkey distribution from mozilla.org:
 http://www.mozilla.org/js/spidermonkey shows which releases are available.
-C<js-1.5.tar.gz> has been proven to work.
+C<js-1.6.tar.gz> has been proven to work.
 
 Untar it at the same directory level as you just untarred the 
 C<JavaScript::SpiderMonkey> distribution you're currently reading.
 So, if you're currently in C</my/path/JavaScript-SpiderMonkey-v.vv>, do
 this:
 
-    cp js-1.5.tar.gz /my/path
+    cp js-1.6.tar.gz /my/path
     cd /my/path
-    tar zxfv js-1.5.tar.gz
+    tar zxfv js-1.6.tar.gz
 
 Then, compile the SpiderMonkey distribution, if you're on Linux, 
 just use:
@@ -598,7 +614,7 @@ are at the same level:
     [/my/path]$ ls
     JavaScript-SpiderMonkey-v.vv
     js
-    js-1.5-rc3a.tar.gz
+    js-1.6.tar.gz
     [/my/path]$
 
 (Note that you *can* untar the SpiderMonkey distribution elsewhere,
@@ -628,8 +644,13 @@ To build JavaScript-SpiderMonkey with E4X (ECMAScript for XML) support:
 
     perl Makefile.PL -E4X
 
-Please note that E4X support is not included in the SpiderMonkey JS1.5 final release. You will probably
-need to download more recent sourcecode directly from CVS.   
+Please note that E4X support is only supported since SpiderMonkey release 1.6.
+
+=head1 THREAD SAFETY
+
+To build JavaScript-SpiderMonkey when using a thread safe version of SpiderMonkey:
+
+   perl Makefile.PL -JS_THREADSAFE
 
 =head1 AUTHORS
 
@@ -639,7 +660,7 @@ need to download more recent sourcecode directly from CVS.
 =head1 COPYRIGHT AND LICENSE
 
   Copyright (c) 2002-2005 Mike Schilli
-  Copyright (c) 2006 Thomas Busch
+  Copyright (c) 2006-2007 Thomas Busch
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself. 
